<?php
if ( !defined( 'ABSPATH' ) ) exit();

if ( ! class_exists('OVAM_Meta_Box') ) {
	class OVAM_Meta_Box {
		public function __construct() {
			add_action( 'add_meta_boxes', array( $this, 'add_meta_box' ) );
			add_action( 'save_post', array( $this, 'save'), 10, 3 );
			add_action( 'edit_form_after_title', array( $this, 'add_shortcode' ), 10, 1 );
		}

		/**
		 * Adds the meta box container.
		 */
		public function add_meta_box( $post_type ) {
			// Limit meta box to certain post types.
			$post_types = array( 'ova-megamenu' );

			if ( in_array( $post_type, $post_types ) ) {
				add_meta_box(
					'ova_megamenu_metabox',
					esc_html__( 'Mega Menu Settings', 'ova-megamenu' ),
					array( $this, 'render_meta_box_content' ),
					$post_type,
					'advanced',
					'high'
				);
			}
		}

		/**
		 * Save the meta when the post is saved.
		 *
		 * @param int $post_id The ID of the post being saved.
		 */
		public function save( $post_id, $post, $update ) {

			/*
			 * We need to verify this came from the our screen and with proper authorization,
			 * because save_post can be triggered at other times.
			 */

			// Check if our nonce is set.
			if ( ! isset( $_POST['ova_megamenu_metabox_nonce'] ) ) {
				return $post_id;
			}

			$nonce = $_POST['ova_megamenu_metabox_nonce'];

			// Verify that the nonce is valid.
			if ( ! wp_verify_nonce( $nonce, 'ova_megamenu_metabox' ) ) {
				return $post_id;
			}

			/*
			 * If this is an autosave, our form has not been submitted,
			 * so we don't want to do anything.
			 */
			if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
				return $post_id;
			}

			// Check the user's permissions.
			if ( 'ova-megamenu' == $_POST['post_type'] ) {
				if ( ! current_user_can( 'edit_post', $post_id ) ) {
					return $post_id;
				}

			} else {
				return $post_id;
			}

			/* OK, it's safe for us to save the data now. */

			// Sanitize the user input.
			$ova_megamenu_desktop = isset( $_POST['ova_megamenu_desktop'] ) ?  array_filter( $_POST['ova_megamenu_desktop'] ) : array();
			$ova_megamenu_desktop = array_values( $ova_megamenu_desktop );
			$ova_megamenu_desktop = ova_megamenu_recursive_sanitize_metabox( $ova_megamenu_desktop );

			$ova_megamenu_tablet = isset( $_POST['ova_megamenu_tablet'] ) ?  array_filter( $_POST['ova_megamenu_tablet'] ) : array();
			$ova_megamenu_tablet = array_values( $ova_megamenu_tablet );
			$ova_megamenu_tablet = ova_megamenu_recursive_sanitize_metabox( $ova_megamenu_tablet );

			$ova_megamenu_mobile = isset( $_POST['ova_megamenu_mobile'] ) ?  array_filter( $_POST['ova_megamenu_mobile'] ) : array();
			$ova_megamenu_mobile = array_values( $ova_megamenu_mobile );
			$ova_megamenu_mobile = ova_megamenu_recursive_sanitize_metabox( $ova_megamenu_mobile );

			$ova_megamenu = isset( $_POST['ova_megamenu'] ) ? array_filter( $_POST['ova_megamenu'] ) : array();
			$ova_megamenu = ova_recursive_sanitize_text_field( $ova_megamenu );

			// Update the meta field.
			update_post_meta( $post_id, 'ova_megamenu_desktop', $ova_megamenu_desktop );
			update_post_meta( $post_id, 'ova_megamenu_tablet', $ova_megamenu_tablet );
			update_post_meta( $post_id, 'ova_megamenu_mobile', $ova_megamenu_mobile );
			update_post_meta( $post_id, 'ova_megamenu', $ova_megamenu );
		}

		public function add_shortcode( $post ){
			if ( get_post_type( $post ) !== 'ova-megamenu' ) {
				return;
			}
			$shortcode = ova_megamenu_get_shortcode_by_id( $post->ID );
			?>
			<p class="description">
				<label for="ova-megamenu-shortcode">
					<?php echo esc_html( __( "Copy this shortcode and paste it into your menu item:", 'ova-megamenu' ) ); ?>
				</label>
				<span class="ova-megamenu-block wp-ui-highlight"><input type="text" id="ova-megamenu-shortcode" onfocus="this.select();" readonly="readonly" class="large-text code" value="<?php echo esc_attr( $shortcode ); ?>" /></span>
			</p>
			<?php
		}


		/**
		 * Render Meta Box content.
		 *
		 * @param WP_Post $post The post object.
		 */
		public function render_meta_box_content( $post ) {

			// Add an nonce field so we can check for it later.
			wp_nonce_field( 'ova_megamenu_metabox', 'ova_megamenu_metabox_nonce' );

			// Use get_post_meta to retrieve an existing value from the database.
			$tab_arr = array(
				'desktop' => esc_html__( 'Desktop', 'ova-megamenu' ),
				'tablet' => esc_html__( 'Tablet', 'ova-megamenu' ),
				'mobile' => esc_html__( 'Mobile', 'ova-megamenu' ),
			);
			$widgets = ova_megamenu_get_type_item();
			// Display the form, using the current value.
			$ova_megamenu = get_post_meta( $post->ID, 'ova_megamenu', true );
			$width_style = isset( $ova_megamenu['width_style'] ) ? $ova_megamenu['width_style'] : 'full-width';
			?>
			<div id="ova_megamenu_metabox_container" data-nonce="<?php echo esc_attr( wp_create_nonce( 'ova_megamenu_action' ) ); ?>">

				<div class="ova_megamenu_general">
					<table class="form-table">
						<tbody>
							<tr>
								<th scope="row"><?php esc_html_e( 'Width Style', 'ova-megamenu' ); ?></th>
								<td>
									<label for="">
										<input name="ova_megamenu[width_style]" type="radio" <?php checked( $width_style, 'full-width' ); ?> value="full-width">
										<?php esc_html_e( 'Full Width', 'ova-megamenu' ); ?>
									</label>
									<label for="">
										<input name="ova_megamenu[width_style]" type="radio" <?php checked( $width_style, 'container' ); ?> value="container">
										<?php esc_html_e( 'Container', 'ova-megamenu' ); ?>
									</label>
								</td>
							</tr>
						</tbody>
					</table>
				</div>

				<div class="ova_megamenu_tabs">

					<h2 class="nav-tab-wrapper">
						<?php foreach ( $tab_arr as $key => $tab ): ?>
							<a href="#ova_megamenu_<?php echo $key; ?>" data-id="ova_megamenu_<?php echo $key; ?>" class="nav-tab"><?php echo esc_html( $tab ); ?></a>
						<?php endforeach; ?>
					</h2>
					<?php foreach ( $tab_arr as $tab_name => $tab ): ?>
						<?php
						$ova_megamenu = get_post_meta( $post->ID, 'ova_megamenu_'.$tab_name, true );
						$class_active = empty( $ova_megamenu ) ? 'is-active' : '';
						?>
						<div class="tabs-content" id="ova_megamenu_<?php echo $tab_name; ?>" data-tab="<?php echo $tab_name; ?>">
							<h3 class="tab-title"><?php echo esc_html( $tab ); ?></h3>
							<ul class="ova_content_rows">
								<?php if ( ! empty( $ova_megamenu ) ): ?>
									<?php foreach ( $ova_megamenu as $k => $row ): ?>

										<li class="ova_megamenu_row card" data-row="<?php echo esc_attr( $k ); ?>">
											<ul class="ova_megamenu_columns">
												<?php if ( $row ): ?>
													<?php foreach ( $row as $j => $value ): ?>
														<?php $column_width = isset( $value['column_width'] ) ? $value['column_width'] : ''; ?>
														<li class="ova_megamenu_column card"
															style="width: <?php echo esc_attr( $column_width.'%' ); ?>;"
															data-column="<?php echo esc_attr( $j ); ?>"
															data-row="<?php echo esc_attr( $k ); ?>">
															<button type="button" class="ova_megamenu_remove_column button button-small button-secondary">&#x2715;</button>
															<button type="button" class="ova_megamenu_edit_width button button-small button-secondary"><span class="dashicons dashicons-edit"></span></button>
															<div class="ova_megamenu_resize"></div>
															
															<div class="show_column_percent"><?php echo esc_html( $column_width.'%' ); ?></div>

															<input type="number" name="ova_megamenu_<?php echo $tab_name; ?>[<?php echo $k; ?>][<?php echo $j; ?>][column_width]" step="0.1" min="1" class="ova_megamenu_column_width" value="<?php echo esc_attr( $column_width ); ?>">
															<ul class="ova_megamenu_widgets">
																<?php
																	$widget_items = isset( $value['widget'] ) ? $value['widget'] : array();
																?>
																<?php if ( ! empty( $widget_items ) ): ?>
																	<?php foreach ($widget_items as $key => $val): ?>
																		
																		<li class="ova_megamenu_widget_item card" data-widget="<?php echo esc_attr( $key ); ?>" data-column="<?php echo esc_attr( $j ); ?>" data-row="<?php echo esc_attr( $k ); ?>">

																				<button type="button" class="ova_megamenu_remove_widget button button-small button-primary">&#x2715;</button>
																				<table class="form-table">
																				<tbody>

																				<tr>
																					<?php
																					$widget_type = isset( $val['type'] ) ? $val['type'] : '';
																					?>
																					<td><label for=""><strong><?php esc_html_e( 'Choose a type', 'ova-megamenu' ); ?></strong></label>
																						<select class="ova_megamenu_widget" name="ova_megamenu_<?php echo $tab_name; ?>[<?php echo $k; ?>][<?php echo $j; ?>][widget][<?php echo $key; ?>][type]" id="">
																							<option selected="selected" value=""><?php esc_html_e( '--- Type ---', 'ova-megamenu' ); ?></option>
																							<?php if ( ! empty( $widgets ) ): ?>
																								<?php foreach ($widgets as $y => $type): ?>
																									<option <?php selected( $widget_type, $y ); ?> value="<?php echo esc_attr( $y ); ?>"><?php echo esc_html( $type ); ?></option>
																								<?php endforeach; ?>
																							<?php endif; ?>
																						</select>
																					</td>
																				</tr>


																				<?php $heading = isset( $val['heading'] ) ? $val['heading'] : ''; ?>
																				<tr>
																					<td><label for=""><strong><?php esc_html_e( 'Heading', 'ova-megamenu' ); ?></strong></label>
																					<input name="ova_megamenu_<?php echo $tab_name; ?>[<?php echo $k; ?>][<?php echo $j; ?>][widget][<?php echo $key; ?>][heading]" type="text" placeholder="<?php esc_attr_e( 'Enter heading', 'ova-megamenu' ); ?>" id="" value="<?php echo esc_attr( $heading ); ?>" class="large-text"></td>
																				</tr>

																				<?php  $shortcode = isset( $val['shortcode'] ) ? $val['shortcode'] : '';  ?>
																				<tr class="ova_megamenu_field <?php echo $widget_type == 'shortcode' ? 'active' : ''; ?>" data-id="shortcode">
																					<td><label for=""><strong><?php esc_html_e( 'Shortcode', 'ova-megamenu' ); ?></strong></label>
																					<input name="ova_megamenu_<?php echo $tab_name; ?>[<?php echo $k; ?>][<?php echo $j; ?>][widget][<?php echo $key; ?>][shortcode]" type="text" placeholder="<?php esc_attr_e( 'Enter shortcode', 'ova-megamenu' ); ?>" id="" value="<?php echo esc_attr( $shortcode ); ?>" class="large-text"></td>
																				</tr>

																					<tr class="ova_megamenu_field <?php echo $widget_type == 'text' ? 'active' : ''; ?>" data-id="text">
																						<td>
																							<label for=""><strong><?php esc_html_e( 'Text', 'ova-megamenu' ); ?></strong></label>
																							<?php
																								$settings  = array(
																									'textarea_name' => 'ova_megamenu_'.$tab_name.'['.$k.']['.$j.'][widget]['.$key.'][text]',
																									'textarea_rows' => 10,
																									'editor_height' => 230,
																									'wpautop' => false
																								);
																								$content = isset( $val['text'] ) ? $val['text'] : '';
																								wp_editor( wpautop( $content ), 'ova_megamenu_'.uniqid(), $settings );
																							?>
																						</td>
																					</tr>
																					<?php
																					$menu_type = isset( $val['menu_type'] ) ? $val['menu_type'] : 'add-item';
																					?>
																					<tr class="ova_megamenu_field <?php echo $widget_type == 'menu' ? 'active' : ''; ?>" data-id="menu">
																						<td>
																							<label for=""><?php esc_html_e( 'Type:', 'ova-megamenu' ); ?></label>
																							
																							<span><input  class="menu_type" name="ova_megamenu_<?php echo $tab_name; ?>[<?php echo $k; ?>][<?php echo $j; ?>][widget][<?php echo $key; ?>][menu_type]" <?php checked( $menu_type, 'add-item') ?> type="radio" value="add-item">
																								<?php esc_html_e( 'Add items', 'ova-megamenu' ); ?>
																							</span>

																							<span><input class="menu_type" name="ova_megamenu_<?php echo $tab_name; ?>[<?php echo $k; ?>][<?php echo $j; ?>][widget][<?php echo $key; ?>][menu_type]" <?php checked( $menu_type, 'select-menu' ); ?> type="radio" value="select-menu">
																								<?php esc_html_e( 'Select menu', 'ova-megamenu' ); ?>
																							</span>
																						</td>

																					</tr>

																					<tr class="ova_megamenu_sub_field <?php echo $widget_type == 'menu' && $menu_type == 'select-menu' ? 'active' : ''; ?>" data-id="select-menu">
																						<?php
																						$nav_menus = ova_megamenu_get_menus();
																						$menu_selected = isset( $val['menu'] ) ? $val['menu'] : '';
																						?>
																						<td>
																							<label for=""><strong><?php esc_html_e( 'Choose a menu', 'ova-megamenu' ); ?></strong></label>
																						
																							<select name="ova_megamenu_<?php echo $tab_name; ?>[<?php echo $k; ?>][<?php echo $j; ?>][widget][<?php echo $key; ?>][menu]" id="">
																								<option value=""><?php esc_html_e( 'Choose a menu', 'ova-megamenu' ); ?></option>
																								<?php if ( ! empty( $nav_menus ) ): ?>
																									<?php foreach ($nav_menus as $obj): ?>
																										<option
																										<?php selected( $menu_selected, $obj->term_id ); ?>
																										value="<?php echo esc_attr( $obj->term_id ); ?>"><?php echo esc_html( $obj->name ); ?></option>
																									<?php endforeach; ?>
																								<?php endif; ?>
																							</select>
																						</td>
																					</tr>

																					<tr class="ova_megamenu_sub_field <?php echo $widget_type == 'menu' && $menu_type == 'add-item' ? 'active' : ''; ?>" data-id="add-item">
																						
																						<td>
																							<?php
																							$menu_items = isset( $val['menu_item'] ) ? $val['menu_item'] : array();
																							$active_bulk_select = ! empty( $menu_items ) ? 'is-active' : '';
																							?>

																							<div class="ova_header">

																									<button type="button" class="
																									<?php echo esc_attr( $active_bulk_select ); ?> ova_megamenu_menu_item_bulk_select button button-small button-secondary">
																										<input type="checkbox" class="menu_item_bulk_select" value="1">
																										<span><?php esc_html_e( 'Bulk Select', 'ova-megamenu' ); ?></span>
																									</button>

																							</div>
																							<ul class="list-menu-item">
																								<?php if ( ! empty( $menu_items ) ): ?>
																									<?php foreach ( $menu_items as $k_item => $menu_item ):
																										$label = isset( $menu_item['label'] ) ? $menu_item['label'] : '';
																										$title = isset( $menu_item['title'] ) ? $menu_item['title'] : '';
																										$class = isset( $menu_item['class'] ) ? $menu_item['class'] : '';
																										$url = isset( $menu_item['url'] ) ? $menu_item['url'] : '';
																										$target = isset( $menu_item['target'] ) ? $menu_item['target'] : '';
																										?>
																										<li class="menu-item">
																											<h4 class="menu-title">
																											<span class="input-title">
																												<input type="checkbox" class="ova_check_menu_item" value="1">
																												<span class="title">
																													<?php echo esc_html( $label ); ?>
																												</span>
																											</span>
																											<span class="icon"><i class="dashicons dashicons-arrow-down"></i></span>
																											</h4>
																											<div class="content">
																												<ul class="list-menu-item-field">
																													<li class="menu-item-field">
																														<label for=""><?php esc_html_e( 'Navigation Label', 'ova-megamenu' ); ?></label>
																														<input
																														type="text"
																														class="menu_item_title large-text"
																														name="ova_megamenu_<?php echo $tab_name; ?>[<?php echo $k; ?>][<?php echo $j; ?>][widget][<?php echo $key; ?>][menu_item][<?php echo $k_item; ?>][label]"
																														placeholder=""
																														value="<?php echo esc_attr( $label ); ?>" />
																													</li>
																													<li class="menu-item-field">
																														<label for=""><?php esc_html_e( 'Link', 'ova-megamenu' ); ?></label>
																														<input
																														type="text"
																														class="large-text"
																														name="ova_megamenu_<?php echo $tab_name; ?>[<?php echo $k; ?>][<?php echo $j; ?>][widget][<?php echo $key; ?>][menu_item][<?php echo $k_item; ?>][url]"
																														placeholder=""
																														value="<?php echo esc_attr( $url ); ?>" />
																													</li>
																													<li class="menu-item-field">
																														<label for=""><?php esc_html_e( 'Title Attribute', 'ova-megamenu' ); ?></label>
																														<input
																														type="text"
																														class="menu_item_title_attr large-text"
																														name="ova_megamenu_<?php echo $tab_name; ?>[<?php echo $k; ?>][<?php echo $j; ?>][widget][<?php echo $key; ?>][menu_item][<?php echo $k_item; ?>][title]"
																														placeholder=""
																														value="<?php echo esc_attr( $title ); ?>" />
																													</li>
																													<li class="menu-item-field">
																														<label for=""><?php esc_html_e( 'CSS Classes', 'ova-megamenu' ); ?></label>
																														<input
																														type="text"
																														class="menu_item_classes large-text"
																														name="ova_megamenu_<?php echo $tab_name; ?>[<?php echo $k; ?>][<?php echo $j; ?>][widget][<?php echo $key; ?>][menu_item][<?php echo $k_item; ?>][class]"
																														placeholder=""
																														value="<?php echo esc_attr( $class ); ?>" />
																													</li>
																													<li class="menu-item-field">
																														<label for="">
																														<input
																														type="checkbox"
																														name="ova_megamenu_<?php echo $tab_name; ?>[<?php echo $k; ?>][<?php echo $j; ?>][widget][<?php echo $key; ?>][menu_item][<?php echo $k_item; ?>][target]"
																														<?php checked( $target, '1' ); ?>
																														value="1" />
																														<?php esc_html_e( 'Open link in a new tab', 'ova-megamenu' ); ?>
																														</label>
																													</li>
																													<li class="menu-item-field footer">
																														<a class="ova_megamenu_remove_menu_item" href="#"><?php esc_html_e( 'Remove', 'ova-megamenu' ); ?></a>
																														<span class="separator">|</span>
																														<a class="ova_megamenu_cancel_menu_item" href="#"><?php esc_html_e( 'Cancel', 'ova-megamenu' ); ?></a>
																													</li>
																												</ul>
																											</div>
																										</li>
																									<?php endforeach; ?>
																								<?php endif; ?>
																							</ul>
																							<div class="ova_footer">
																								
																								<button type="button" class="
																								<?php echo esc_attr( $active_bulk_select ); ?> ova_megamenu_menu_item_bulk_select button button-small button-secondary">
																									<input type="checkbox" class="menu_item_bulk_select" value="1">
																									<span><?php esc_html_e( 'Bulk Select', 'ova-megamenu' ); ?></span>
																								</button>
																							
																								<a href="#" class="ova_menu_item_remove"><?php esc_html_e( 'Remove Selected Items', 'ova-megamenu' ); ?></a>
																								
																							</div>
																							

																							<button type="button"
																							data-btn="<?php esc_attr_e( 'Close', 'ova-megamenu' ); ?>"
																							data-title="<?php esc_attr_e( 'Add menu item', 'ova-megamenu' ); ?>" class="ova_megamenu_add_menu_item button button-secondary"><?php esc_html_e( 'Add menu item', 'ova-megamenu' ); ?></button>

																						</td>
																					</tr>


																				</tbody>
																			</table>

																		</li>
																	<?php endforeach; ?>
																<?php endif; ?>
															</ul>
			
																<button type="button" class="ova_megamenu_add_widget button button-secondary"><?php esc_html_e( 'Add widget', 'ova-megamenu' ); ?></button>

														</li>
													<?php endforeach; ?>
												<?php endif; ?>
											</ul>

												<button type="button" class="ova_megamenu_remove_row button button-small button-primary">&#x2715;</button>
													
												<button type="button" class="ova_megamenu_add_column button button-secondary"><?php esc_html_e( 'Add column', 'ova-megamenu' ); ?></button>
												

										</li>
									<?php endforeach; ?>
								<?php endif; ?>
							</ul>

							<div class="ova-megamenu-copy-data <?php echo esc_attr( $class_active ); ?>">
								<table class="form-table">
									<tbody>
										<tr>
											<th scope="row">
												<label><?php esc_html_e( 'Copy data from tab', 'ova-megamenu' ); ?></label>
												<span class="description"><?php esc_html_e( '( You should save page before copy data )', 'ova-megamenu' ); ?></span>
											</th>
											<td>
												<select class="ova_megamenu_copy">
													<option selected="selected" value=""><?php esc_html_e( 'Select a tab', 'ova-megamenu' ); ?></option>
													<?php foreach ( $tab_arr as $k => $v ):
														if ( $k == $tab_name ):
															continue;
														endif; ?>
														<option value="<?php echo esc_attr( $k ); ?>"><?php echo esc_html( $v ); ?></option>
													<?php endforeach; ?>
													
												</select>
												<button type="button"
												data-post-id="<?php echo esc_attr( $post->ID ); ?>"
												data-tab="<?php echo esc_attr( $tab_name ); ?>"
												data-nonce="<?php echo esc_attr( wp_create_nonce( 'ova_megamenu_copy_update' ) ); ?>"
												class="ova_megamenu_copy_update button button-primary"><?php esc_html_e( 'Update', 'ova-megamenu' ); ?></button>
											</td>
										</tr>
									</tbody>
								</table>
							</div>
							
							<div class="ova_megamenu_btn_row">
								<button type="button"
								id="ova_megamenu_add_row"
								class="button button-primary button-hero">
								<?php esc_html_e( 'Add Row', 'ova-megamenu' ); ?></button>
								<span class="spinner_add_row spinner"></span>
							</div>
						</div>
					<?php endforeach; ?>
					<?php
						$pages = ova_megamenu_get_page_default();
					/* dialog_box */
					?>

				</div>

				<div class="ova_megamenu_dialog_box">
					<ul class="ova_megamenu_accordion">
						<li class="ova_megamenu_accordion_item">
							<h3 class="heading"><?php esc_html_e( 'Pages', 'ova-megamenu' ); ?></h3>
							<div class="content">
								
								<input class="large-text filter_page"
								placeholder="<?php esc_attr_e( 'Seach page', 'ova-megamenu' ); ?>"
								type="text" value="">
								<ul class="list-item list-page">
									<?php if ( $pages ): ?>
										<?php foreach ($pages as $page): ?>
											<li class="item page-item">
												<label for="<?php echo 'page-'.esc_attr( $page->ID  ); ?>">
													<input type="checkbox" id="<?php echo 'page-'.esc_attr( $page->ID  ); ?>" value="<?php echo esc_attr( $page->ID ); ?>">
													<?php echo esc_html( $page->post_title ); ?>
												</label>
											</li>
										<?php endforeach; ?>
									<?php else: ?>
										<p><?php esc_html_e( 'Page not found.', 'ova-megamenu' ); ?></p>
									<?php endif; ?>
								</ul>
								<div class="footer">
									<label for="">
										<input type="checkbox" class="check_all_item" value="1">
										<?php esc_html_e( 'Select All', 'ova-megamenu' ); ?>
									</label>
									<button type="button" class="ova_megamenu_add_to_menu ova_megamenu_add_page_item button button-secondary"><?php esc_html_e( 'Add to menu', 'ova-megamenu' ); ?></button>
								</div>	
								
							</div>
						</li>
						<?php
						$posts = ova_megamenu_get_post_default();
						?>
						<li class="ova_megamenu_accordion_item">
							<h3 class="heading"><?php esc_html_e( 'Posts', 'ova-megamenu' ); ?></h3>
							<div class="content">
								
								<input class="large-text filter_post"
								placeholder="<?php esc_attr_e( 'Seach post', 'ova-megamenu' ); ?>" type="text" value="">
								<ul class="list-item list-post">
									<?php if ( $posts ): ?>
										<?php foreach ( $posts as $post ): ?>
											<li class="item post-item">
												<label for="<?php echo 'post-'.esc_attr( $post->ID  ); ?>">
													<input type="checkbox" id="<?php echo 'post-'.esc_attr( $post->ID  ); ?>" value="<?php echo esc_attr( $post->ID ); ?>">
													<?php echo esc_html( $post->post_title ); ?>
												</label>
											</li>
										<?php endforeach; ?>
									<?php else: ?>
										<p><?php esc_html_e( 'Post not found.', 'ova-megamenu' ); ?></p>
									<?php endif; ?>
								</ul>
								<div class="footer">
									<label for="">
										<input type="checkbox" class="check_all_item" value="1">
										<?php esc_html_e( 'Select All', 'ova-megamenu' ); ?>
									</label>
									<button type="button" class="ova_megamenu_add_to_menu ova_megamenu_add_post_item button button-secondary"><?php esc_html_e( 'Add to menu', 'ova-megamenu' ); ?></button>
								</div>	
								
							</div>
						</li>
						<?php

						$custom_post_types = ova_megamenu_get_custom_post_types();
						if ( ! empty( $custom_post_types ) ) {
							foreach ( $custom_post_types as $post_type ) {
								$custom_posts = ova_megamenu_get_custom_post_type_default( $post_type->name );
								?>
								<li class="ova_megamenu_accordion_item">
									<h3 class="heading"><?php echo esc_html( $post_type->label ); ?></h3>
									<div class="content">
								
										<input class="large-text filter_custom_post_type"
										data-post-type="<?php echo esc_attr( $post_type->name ); ?>"
										placeholder="<?php echo sprintf( esc_attr__( 'Search %s', 'ova-megamenu' ), $post_type->labels->singular_name ) ?>" type="text" value="">
										<ul class="list-item list-custom-post-type">
											<?php if ( ! empty( $custom_posts ) && $custom_posts->have_posts() ): ?>
												<?php while ( $custom_posts->have_posts() ) :
													$custom_posts->the_post();
													$id = get_the_ID();
													$title = get_the_title();
													?>
													<li class="item post-item">
														<label for="<?php echo esc_attr( $post_type->label.'-'.$id  ); ?>">
															<input type="checkbox" id="<?php echo esc_attr( $post_type->label.'-'.$id  ); ?>" value="<?php echo esc_attr( $id ); ?>">
															<?php echo esc_html( $title ); ?>
														</label>
													</li>
												<?php endwhile; ?>

											<?php else: ?>
												<p><?php echo sprintf( esc_html__( '%s not found.', 'ova-megamenu' ), $post_type->labels->singular_name ) ?></p>
											<?php endif; wp_reset_postdata(); ?>
										</ul>
										<div class="footer">
											<label for="">
												<input type="checkbox" class="check_all_item" value="1">
												<?php esc_html_e( 'Select All', 'ova-megamenu' ); ?>
											</label>
											<button type="button"
											data-post-type="<?php echo esc_attr( $post_type->name ); ?>"
											class="ova_megamenu_add_to_menu ova_megamenu_add_custom_post_item button button-secondary"><?php esc_html_e( 'Add to menu', 'ova-megamenu' ); ?></button>
										</div>	
										
									</div>
								</li>
								<?php
							}
						}
						?>

						<li class="ova_megamenu_accordion_item">
							<h3 class="heading"><?php esc_html_e( 'Custom Links', 'ova-megamenu' ); ?></h3>
							<div class="content">
								<table class="form-table">
									<tr>
										<td><label for=""><?php esc_html_e( 'URL', 'ova-megamenu' ); ?></label></td>
										<td><input type="text" class="url_item large-text" placeholder="<?php echo esc_attr( 'https://' ); ?>"></td>
									</tr>
									<tr>
										<td><label for=""><?php esc_html_e( 'Link Text', 'ova-megamenu' ); ?></label></td>
										<td><input type="text" class="link_text_item large-text" placeholder=""></td>
									</tr>
									<tr>
										<td colspan="2">
											<div class="footer">
												<button type="button" class="ova_megamenu_add_to_menu ova_megamenu_add_custom_link button button-secondary"><?php esc_html_e( 'Add to menu', 'ova-megamenu' ); ?></button>
											</div>
										</td>
									</tr>
								</table>
							</div>
						</li>
						<?php
						$categories = ova_megamenu_get_categories_default();
						?>
						<li class="ova_megamenu_accordion_item">
							<h3 class="heading"><?php esc_html_e( 'Categories', 'ova-megamenu' ); ?></h3>
							<div class="content">
								
								<input class="large-text filter_categories"
								placeholder="<?php esc_attr_e( 'Seach category', 'ova-megamenu' ); ?>" type="text" value="">
								<ul class="list-item list-category">
									<?php if ( ! empty( $categories ) ): ?>
										<?php foreach ( $categories as $category ): ?>
											<li class="item category-item">
												<label for="<?php echo 'category-'.esc_attr( $category->term_id  ); ?>">
													<input type="checkbox" id="<?php echo 'category-'.esc_attr( $category->term_id  ); ?>" value="<?php echo esc_attr( $category->term_id ); ?>">
													<?php echo esc_html( $category->name ); ?>
												</label>
											</li>
										<?php endforeach; ?>
									<?php else: ?>
										<p><?php esc_html_e( 'Category not found.', 'ova-megamenu' ); ?></p>
									<?php endif; ?>
								</ul>
								<div class="footer">
									<label for="">
										<input type="checkbox" class="check_all_item" value="1">
										<?php esc_html_e( 'Select All', 'ova-megamenu' ); ?>
									</label>
									<button type="button" class="ova_megamenu_add_to_menu ova_megamenu_add_category_item button button-secondary"><?php esc_html_e( 'Add to menu', 'ova-megamenu' ); ?></button>
								</div>
								
							</div>
						</li>
						<?php
						$custom_taxonomies = ova_megamenu_get_custom_taxonomies();

						if ( ! empty( $custom_taxonomies ) ) {
							foreach ( $custom_taxonomies as $taxonomy ) {
								$terms = ova_megamenu_get_custom_taxonomies_default( $taxonomy->name );
								?>
								<li class="ova_megamenu_accordion_item">
									<h3 class="heading"><?php echo esc_html( $taxonomy->label ); ?></h3>
									<div class="content">
										
										<input class="large-text filter_custom_taxonomies"
										data-taxonomy="<?php echo esc_attr( $taxonomy->name ); ?>"
										placeholder="<?php echo sprintf( esc_attr__( 'Search %s', 'ova-megamenu' ), $taxonomy->labels->singular_name ); ?>" type="text" value="">
										<ul class="list-item list-terms list-<?php echo esc_attr( $taxonomy->name ); ?>">
											<?php if ( ! empty( $terms ) ): ?>
												<?php foreach ( $terms as $term ): ?>
													<li class="item <?php echo esc_attr( $taxonomy->name ); ?>-item">
														<label for="<?php echo esc_attr( $taxonomy->name.'-'.$term->term_id  ); ?>">
															<input type="checkbox" id="<?php echo esc_attr( $taxonomy->name.'-'.$term->term_id  ); ?>" value="<?php echo esc_attr( $term->term_id ); ?>">
															<?php echo esc_html( $term->name ); ?>
														</label>
													</li>
												<?php endforeach; ?>
											<?php else: ?>
												<p><?php echo sprintf( esc_html__( '%s not found.', 'ova-megamenu' ), $taxonomy->labels->singular_name ) ?></p>
											<?php endif; ?>
										</ul>
									
										<div class="footer">
											<label for="">
												<input type="checkbox" class="check_all_item" value="1">
												<?php esc_html_e( 'Select All', 'ova-megamenu' ); ?>
											</label>
											<button type="button"
											data-taxonomy="<?php echo esc_attr( $taxonomy->name ); ?>"
											class="ova_megamenu_add_to_menu ova_megamenu_add_custom_tax_item button button-secondary"><?php esc_html_e( 'Add to menu', 'ova-megamenu' ); ?></button>
										</div>
									</div>
								</li>
								<?php
							}
						}
						?>
						
					</ul>
				</div> <!-- .ova_megamenu_dialog_box -->
			</div><!-- #ova_megamenu_metabox_container -->
			<?php

		}
	}

new OVAM_Meta_Box();
}